@@ -5,7 +5,7 @@ from itertools import tee, zip_longest
 
 
 # Do not update the version manually - it is managed by `bumpversion`.
-__version__ = '4.0.0'
+__version__ = '4.0.1'
 log = logging.getLogger(__name__)
 
 
@@ -25,3 +25,16 @@ def pairwise(
     a, b = tee(iterable)
     _ = next(b, default_value)
     return zip_longest(a, b, fillvalue=default_value)
+
+
+def common_prefix_length(a: str, b: str) -> int:
+    """Return the length of the longest common prefix of a and b.
+
+    >>> common_prefix_length('abcd', 'abce')
+    3
+
+    """
+    for common, (ca, cb) in enumerate(zip(a, b)):
+        if ca != cb:
+            return common
+    return min(len(a), len(b))
\ No newline at end of file
